@@ -1,7 +1,7 @@
 package Plack::Middleware::RearrangeHeaders;
 use strict;
 use warnings;
-use base qw( Plack::Middleware );
+use parent qw( Plack::Middleware );
 
 use HTTP::Headers;
 
