@@ -10,10 +10,14 @@ sub call {
     my $self = shift;
 
     my $res = $self->app->( @_ );
+
+    return $res unless ref $res eq 'ARRAY';
+
     if ($self->framework) {
         Plack::Util::header_set $res->[1], 'X-Framework' => $self->framework;
     }
-    $res;
+
+    return $res;
 }
 
 1;
